==> DiffBind_2.6.0.tar.gz: DiffBind/R/cpp_wrapper.R <==
################################################
## cpp_wrapper.R -- wrap C/C++ functions in R ##
## first created: 2014 03 12                  ##
## Gord Brown                                 ##
## CR-UK Cambridge Institute                  ##
################################################

################################################
## Entry Points to C/C++ Routines             ##
################################################

## cpp_count_reads -- count reads on intervals

cpp_count_reads <- function(bamfile,insertLength,fileType,bufferSize,
                            intervals,bWithoutDupes,summits,minMappingQual=0) {
  icount <- length(intervals[[1]])
  counts <- vector(mode="integer",length=icount)
  if (!missing(summits)) {
    summits.vec <- vector(mode="integer",length=icount)
    heights.vec <- vector(mode="integer",length=icount)
    bSummits = TRUE
  } else {
    summits.vec <- vector()
    heights.vec <- vector()
    bSummits = FALSE
  }
  bamfile <- path.expand(bamfile)
  libsize <- .Call("croi_count_reads",bamfile,
                   as.integer(insertLength),
                   as.integer(fileType),
                   as.integer(bufferSize),
                   as.integer(minMappingQual),
                   as.character(intervals[[1]]),
                   as.integer(intervals[[2]]),
                   as.integer(intervals[[3]]),
                   as.integer(icount),
                   as.logical(bWithoutDupes),
                   as.logical(bSummits),
                   counts,
                   summits.vec,
                   heights.vec)
  counts[counts==0]=1

  widths = intervals[,3] - intervals[,2]
  rpkm = (counts/(widths/1000))/(libsize/1E6)

  result <- list(counts=counts,rpkm=rpkm,libsize=libsize)
  if (bSummits==T) {
    result$summits <- summits.vec;
    result$heights <- heights.vec;
  }
  return(result)
}

==> DiffBind_2.6.6.tar.gz: DiffBind/R/cpp_wrapper.R <==
################################################
## cpp_wrapper.R -- wrap C/C++ functions in R ##
## first created: 2014 03 12                  ##
## Gord Brown                                 ##
## CR-UK Cambridge Institute                  ##
################################################

################################################
## Entry Points to C/C++ Routines             ##
################################################

## cpp_count_reads -- count reads on intervals

cpp_count_reads <- function(bamfile,insertLength,fileType,bufferSize,
                            intervals,bWithoutDupes,summits,minMappingQual=0) {
  icount <- length(intervals[[1]])
  counts <- vector(mode="integer",length=icount)
  if (!missing(summits)) {
    summits.vec <- vector(mode="integer",length=icount)
    heights.vec <- vector(mode="integer",length=icount)
    bSummits = TRUE
  } else {
    summits.vec <- vector()
    heights.vec <- vector()
    bSummits = FALSE
  }
  bamfile <- path.expand(bamfile)
  libsize <- .Call("croi_count_reads",PACKAGE='DiffBind',
                   bamfile,
                   as.integer(insertLength),
                   as.integer(fileType),
                   as.integer(bufferSize),
                   as.integer(minMappingQual),
                   as.character(intervals[[1]]),
                   as.integer(intervals[[2]]),
                   as.integer(intervals[[3]]),
                   as.integer(icount),
                   as.logical(bWithoutDupes),
                   as.logical(bSummits),
                   counts,
                   summits.vec,
                   heights.vec)
  counts[counts==0]=1

  widths = intervals[,3] - intervals[,2]
  rpkm = (counts/(widths/1000))/(libsize/1E6)

  result <- list(counts=counts,rpkm=rpkm,libsize=libsize)
  if (bSummits==T) {
    result$summits <- summits.vec;
    result$heights <- heights.vec;
  }
  return(result)
}
